idc\_index package
==================

.. automodule:: idc_index
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

idc\_index.index module
-----------------------

.. automodule:: idc_index.index
   :members:
   :undoc-members:
   :show-inheritance:
